@@ -23,8 +23,8 @@ class Article:
         return self.title and self.text
 
 
-def fetch_article(url, fmt, dump_cmd):
-    parser = WebExtractor(url)
+def fetch_article(url, baseurl, fmt, dump_cmd):
+    parser = WebExtractor(url, baseurl)
 
     art = Article()
     art.title = parser.title
@@ -43,8 +43,17 @@ def fetch_article(url, fmt, dump_cmd):
     return art
 
 
-def to_filename(title):
-    return '{}.md'.format(title.strip().lower().replace(' ', '-'))
+def to_filename(title, fmt):
+    ext_mapping = {
+        'text': '.txt',
+        'md': '.md',
+        'html': '.html',
+        'dump': '.txt'
+    }
+
+    return '{}{}'.format(
+        title.strip().lower().replace(' ', '-'),
+        ext_mapping[fmt])
 
 
 @contextlib.contextmanager
@@ -60,8 +69,8 @@ def prepare_args():
     out_formats = ('html', 'md', 'text', 'dump')
 
     parser = argparse.ArgumentParser(
-        description='Fetch and parse web page and send it to kindle'
-    )
+        description='Displays readable contents of web pages in various '
+                    'formats.')
 
     parser.add_argument(
         '-t', '--to', choices=out_formats, default='text',
@@ -80,21 +89,29 @@ def prepare_args():
              'article contents')
     parser.add_argument(
         '--dump-cmd', default='links -dump', metavar='CMD',
-        help='command to which URL is passed when `-F dump` is used; '
+        help='command to which URL is passed when `-t dump` is used; '
              'default: links -dump')
+    parser.add_argument(
+        '--baseurl', metavar='URL',
+        help='when webarchive\'s input is a local file or standard input, this '
+            'parameter can be used to hint about the source of archived '
+            'content; it is used to e.g. resolve relative links')
     parser.add_argument(
         '-f', '--force', action='store_true',
         help='forces overwriting output files')
     parser.add_argument(
         '--version', action='version', version='%(prog)s {}'.format(version))
-    parser.add_argument('url', help='URL to be archived')
+    parser.add_argument(
+        'url',
+        help='URL to be archived; can be http(s) URL, local file or a dash "-" '
+             'to read contents from standard input')
     return parser.parse_args()
 
 
 def main():
     args = prepare_args()
 
-    article = fetch_article(args.url, args.to, args.dump_cmd)
+    article = fetch_article(args.url, args.baseurl, args.to, args.dump_cmd)
     if not article.initialized:
         eprint('Unable to fetch article')
         return 1
@@ -106,7 +123,7 @@ def main():
     # deduce save file path
     savepath_deduced = (args.save == '')
     if args.save == '':
-        args.save = to_filename(article.title)
+        args.save = to_filename(article.title, args.to)
 
     if args.save and os.path.exists(args.save) and not args.force:
         eprint('File exists, refusing overwriting: "{}"'.format(args.save))
